California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 042 - PUBLIC INFORMATION. OPEN MEETINGS. STATE REIMBURSEMENT TO LOCAL AGENCIES. LEGISLATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1365686 | YES ON 42, THE PUBLIC'S RIGHT TO KNOW ACT, SPONSORED BY FIREFIGHTERS & BUILDING TRADES ORGANIZATIONS | SUPPORT